package net.greenfieldtech.cloudonixsdk.cloudonixdialer.activities;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.support.v7.app.ActionBar;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.Gravity;
import android.view.MenuItem;
import android.view.View;
import android.widget.TextView;
import butterknife.BindView;
import butterknife.ButterKnife;
import net.greenfieldtech.cloudonixsdk.cloudonixdialer.R;

/**
 * Created by alex on 19.04.16.
 */

public abstract class BaseActivity extends AppCompatActivity {

  @Nullable
  @BindView(R.id.toolbar)
  Toolbar toolbar;

  @Override
  protected void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);
    setContentView(getLayoutResource());
    ButterKnife.bind(this);

    if (toolbar != null) {
      setSupportActionBar(toolbar);
      ActionBar supportActionBar = getSupportActionBar();
      if (supportActionBar != null) {
        supportActionBar.setDisplayHomeAsUpEnabled(false);
        String title = null;
        if (savedInstanceState != null) {
          title = savedInstanceState.getString("title");
        }
        supportActionBar.setTitle(title);
      }
    }
  }

  public void customizeToolbar() {
    for (int i = 0; i < toolbar.getChildCount(); i++) {
      View view = toolbar.getChildAt(i);
      if (view instanceof TextView) {
        Toolbar.LayoutParams params = new Toolbar.LayoutParams(Toolbar.LayoutParams.WRAP_CONTENT,
            Toolbar.LayoutParams.MATCH_PARENT);
        params.gravity = Gravity.CENTER_HORIZONTAL;
        view.setLayoutParams(params);
      }
    }
  }

  @Override
  protected void onSaveInstanceState(Bundle outState) {
    super.onSaveInstanceState(outState);
    ActionBar supportActionBar = getSupportActionBar();
    if (supportActionBar != null) {
      CharSequence title = supportActionBar.getTitle();
      if (title != null) {
        outState.putString("title", title.toString());
      }
    }
  }

  @Override
  public boolean onOptionsItemSelected(MenuItem item) {
    switch (item.getItemId()) {
      case android.R.id.home:
        onBackPressed();
        return true;
      default:
        return super.onOptionsItemSelected(item);
    }
  }

  public void enableBackButton() {
    if (getSupportActionBar() != null) {
      getSupportActionBar().setDisplayHomeAsUpEnabled(true);
    }
  }

  public void setTitleRes(int title) {
    if (getSupportActionBar() != null) {
      setTitle(getString(title));
    }
  }

  public void setTitle(String title) {
    if (getSupportActionBar() != null) {
      getSupportActionBar().setTitle(title);
    }
  }

  protected abstract int getLayoutResource();

  public void addFragment(Fragment fragment, int containerId, String tag) {
    FragmentManager fragmentManager = getSupportFragmentManager();
    fragmentManager.beginTransaction()
        .setCustomAnimations(android.R.anim.fade_in, android.R.anim.fade_out,
            android.R.anim.fade_in, android.R.anim.fade_out)
        .add(containerId, fragment, tag)
        .addToBackStack(tag)
        .commit();
  }

}
