package net.greenfieldtech.cloudonixsdk.cloudonixdialer.adapters;

import android.content.Context;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;
import butterknife.BindView;
import butterknife.ButterKnife;
import java.util.ArrayList;
import net.greenfieldtech.cloudonixsdk.cloudonixdialer.R;
import net.greenfieldtech.cloudonixsdk.cloudonixdialer.models.RecentCall;

/**
 * Created by alex on 20.04.16.
 */

public class RecentCallsAdapter extends RecyclerView.Adapter<RecentCallsAdapter.ViewHolder> {

  public static final int RESOURCE = R.layout.list_item_recent_call;

  private ArrayList<RecentCall> results;
  private Context context;
  private Callback callback;

  public RecentCallsAdapter(Context context, ArrayList<RecentCall> results) {
    this.context = context;
    this.results = results;
  }

  @Override
  public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
    View view = LayoutInflater.from(parent.getContext()).inflate(RESOURCE, parent, false);
    return new ViewHolder(view);
  }

  @Override
  public void onBindViewHolder(final RecentCallsAdapter.ViewHolder holder, final int position) {
    final RecentCall item = results.get(position);

    holder.tvCallNumber.setText(item.getPhoneNumber());
    holder.tvUserName.setText(item.getUserName());
    holder.tvCallDate.setText(item.getCallDate());

    if (item.isIncoming()) {
      if (item.isMissed()) {
        holder.ivCallType.setImageResource(R.drawable.ic_missed_call);
      } else {
        holder.ivCallType.setImageResource(R.drawable.ic_incomming);
      }
    }

    holder.root.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View view) {
        if (callback != null) {
          callback.onCallClick(item.getPhoneNumber());
        }
      }
    });
  }

  public void addItems(ArrayList<RecentCall> additional) {
    results.addAll(additional);
    notifyDataSetChanged();
  }

  public ArrayList<RecentCall> getAllItems() {
    return results;
  }

  @Override
  public int getItemCount() {
    return results.size();
  }

  public void setCallback(Callback callback) {
    this.callback = callback;
  }

  public interface Callback {

    void onCallClick(String contactNumber);
  }

  static class ViewHolder extends RecyclerView.ViewHolder {

    @BindView(R.id.item_call)
    RelativeLayout root;
    @BindView(R.id.iv_avatar)
    ImageView ivAvatar;
    @BindView(R.id.tv_current_call_number)
    TextView tvCallNumber;
    @BindView(R.id.iv_call_type)
    ImageView ivCallType;
    @BindView(R.id.tv_user_name)
    TextView tvUserName;
    @BindView(R.id.tv_call_date)
    TextView tvCallDate;

    public ViewHolder(View view) {
      super(view);
      ButterKnife.bind(this, view);
    }
  }

}